module ParserBackEnd
  require 'radius'
  include ParserCommon
  
  def parse_page_edit(page)
    if page._type == 'Page'
      layout_content = page.design.layout.content.force_encoding('UTF-8') rescue ''
      context = parser_context_edit(page)
      parser = Radius::Parser.new(context, :tag_prefix => 'r')
      parser.parse(parser.parse(layout_content))
    end
  end
  
  def parser_context_edit(page, attributes = {})
    Radius::Context.new do |c|
      c.define_tag 'ad_banner' do |tag|
        res = ''
        ad_banner = AdBanner.find(tag.attr["id"]) rescue nil
        if ad_banner
          res << "<script type='text/javascript'>
                    $(document).ready(function(){ $('#slideshow-#{ad_banner.title.dehumanize}').cycle({delay: -1000, fx: '#{ad_banner.ad_fx.nil?? 'fade': ad_banner.ad_fx}', timeoutFn: getTimeout }); });
                    </script>"
          res << "<div id='slideshow-#{ad_banner.title.dehumanize}'>"
          ad_banner.ad_images.each do |ad_image|
            res << "<img src='#{ad_image.file}' "
            res << "alt='#{ad_image.picture_intro || ' '}' "
            res << "time_to_next='#{ad_image.get_delay_time}' "
            res << "link_open='#{ad_image.link_open}' "
            res << "link_url='#{(ad_banner.direct_to_after_click?? ad_image.out_link : ad_banner.context) || ' '}' "
            res << "/>"
          end
          res << "</div>"
        end
      end
      c.define_tag 'content' do |tag|
        ret = ''
        if (tag.attributes["main"] == "true" && !page.module_app.nil?)
          ret << "<div id='appfrontend' class='dymanic_load' path='/panel/#{page.module_app.key}/front_end/#{page.app_frontend_url}?inner=true&page_id=#{page.id}"
          ret << "&category_id=#{page.category}" if page[:category]
          ret << "'></div>"
        else
          part = page.page_parts.detect{ |p| p.name.to_s == tag.attr['name'].to_s }
          ret << "<div id='#{tag.attr['name']}' part_id='#{part.id}' class='editable' style='border:solid 1px; margin:5px; padding:5px;'>"
          ret << "<div class='edit_link' style='display:none'>"
          ret << " <a href='#{edit_admin_page_part_path(part.id)}' class='nav'>#{t(:edit)}</a>"
          ret << '</div>'
          case part.kind
            when 'text'
              ret << part.i18n_variable[I18n.locale] rescue ''
            when 'module_widget'
              if part[:category]
                ret << "<div class='dymanic_load' path='/panel/#{part.module_app.key}/widget/#{part.widget_path}?category_id=#{part[:category]}'></div>"
              else
                ret << "<div class='dymanic_load' path='/panel/#{part.module_app.key}/widget/#{part.widget_path}'></div>"
              end
            when 'public_r_tag'
              ret << "<r:#{part.public_r_tag} id='#{part.public_r_tag_object_id}'/>"
            else
              ''
          end
          ret << '</div>'
        end
      end      
      c.define_tag 'image' do |tag|
        # image = page.custom_images.detect{|image| image.name.eql?(tag.attr['name']) }
        # image = page.design.custom_images.detect{|image| image.name.eql?(tag.attr['name']) } unless image
        image = page.design.images.detect{|image| image.name.eql?(tag.attr['name']) } unless image
        if image
          res = "<img src=#{image.file.url} "
          tag.attr.each do |l|
            res << "#{l[0]}='#{l[1]}' "
          end
          res << '>'
        end
      end
      c.define_tag 'javascripts' do |tag|
        res = ''
        res << "<script type='text/javascript' src='/static/jquery.js'></script>"
        res << "<script type='text/javascript' src='/static/jquery.cycle.all.latest.js'></script>"
        res << "<script type='text/javascript' src='/static/kernel.js'></script>"
        res << "<script type='text/javascript' src='/assets/event.js'></script>"
        page.design.javascripts.each do |js|
          res << "<script type='text/javascript' src='#{js.file.url}'></script>"
        end
        res
      end
      c.define_tag 'language_bar' do
        @site.in_use_locales.map{ |locale|
          lang = I18nVariable.first(:conditions => {:key => locale})[locale]
          if I18n.locale.to_s.eql?(locale)
            lang
          else
            "<a href='?locale=#{locale}'>#{lang}</a>"
          end
        }.join(' | ')
      end
      c.define_tag 'link' do |tag|
        item = Item.first(:conditions => { :full_name => tag.attr['name'] })
        ret = ''
        ret << "<a href='"
        ret << eval("admin_#{item._type.downcase}_path(item.id)")
        ret << "' class='nav'>"
        ret << item.i18n_variable[I18n.locale]
        ret << "</a>"
      end
      c.define_tag 'menu' do |tag|
        home = get_homepage
        menu = page.design.layout.menu
        menu_level(home, 0, menu, true)
      end
      c.define_tag 'meta' do |tag|
        "<meta name='bob' content=#{@site.school} />"
      end
      c.define_tag 'stylesheets' do |tag|
        res = ''
        res << "<link href='#{page.design.reset_css.file.url}' rel='stylesheet' type='text/css' />" if page.design.reset_css
        res << "<link href='#{page.design.default_css.file.url}' rel='stylesheet' type='text/css' />" if page.design.default_css
        theme = page.design.themes.detect{ |d| d.id == page.theme_id  }
        res << "<link href='#{theme.file.url}' rel='stylesheet' type='text/css' />" if theme
        res
      end
      c.define_tag 'title' do |tag|
        "<title>#{page.title ? page.title : page.i18n_variable[I18n.locale]}</title>"
      end
    end
  end
  
  def self.included(base)
    base.send :helper_method, :parse_page_edit if base.respond_to? :helper_method
  end

end
