module ParserFrontEnd
  require 'radius'
  include ParserCommon

  def parser_context(page, attributes = {}, id = nil)
    Radius::Context.new do |c|
      c.define_tag 'ad_banner' do |tag|
        res = ''
        ad_banner = AdBanner.find(tag.attr["id"]) rescue nil
        if ad_banner && ad_banner.display?
          res << "<script type='text/javascript'>
                  $(document).ready(function(){ $('#slideshow-#{ad_banner.title.dehumanize}').cycle({delay: -1000, fx: '#{ad_banner.ad_fx.nil?? 'fade': ad_banner.ad_fx}', timeoutFn: getTimeout }); });
                  </script>"
          res << "<div id='slideshow-#{ad_banner.title.dehumanize}'>"
           ad_banner.ad_images.each do |ad_image|
             res << "<img src='#{ad_image.file}' "
             res << "alt='#{ad_image.picture_intro || ' '}' "
             res << "time_to_next='#{ad_image.get_delay_time}' "
             res << "link_open='#{ad_image.link_open}' "
             res << "link_url='#{(ad_banner.direct_to_after_click?? ad_image.out_link : ad_banner.context) || ' '}' "
             res << "/>"
            end
          res << "</div>"
        end
        res
      end
      c.define_tag 'content' do |tag|
        ret = ''
        if (tag.attributes["main"] == "true" && !page.module_app.nil?)
          ret << "<div id='appfrontend' class='dymanic_load' path='/panel/#{page.module_app.key}/front_end/#{page.app_frontend_url}"
          ret << "/#{id}" if id
          ret << "?inner=true&page_id=#{page.id}"
          ret << "&category_id=#{page.category}" if page[:category]
          ret << "'></div>"
        else
          part = page.page_parts.detect{ |p| p.name.to_s == tag.attr['name'].to_s } rescue nil
          case part.kind
          when 'text'
            ret << part.i18n_variable[I18n.locale] rescue ''
          when 'module_widget'
            if part[:category]
              ret << "<div class='dymanic_load' path='/panel/#{part.module_app.key}/widget/#{part.widget_path}?inner=true&category_id=#{part[:category]}'></div>"
            else
              ret << "<div class='dymanic_load' path='/panel/#{part.module_app.key}/widget/#{part.widget_path}?inner=true'></div>"
            end
          when 'public_r_tag'
            ret << "<r:#{part.public_r_tag} id='#{part.public_r_tag_object_id}'/>"
          else
              ''
          end
        end
        ret
      end
      c.define_tag 'image' do |tag|
        # image = page.custom_images.detect{|image| image.name.eql?(tag.attr['name']) }
        # image = page.design.custom_images.detect{|image| image.name.eql?(tag.attr['name']) } unless image
        image = page.design.images.detect{|image| image.name.eql?(tag.attr['name']) } unless image
        if image
          res = "<img src=#{image.file.url} "
          tag.attr.each do |l|
            res << "#{l[0]}='#{l[1]}' "
          end
          res << '>'
        end
      end
      c.define_tag 'language_bar' do
        @site.in_use_locales.map{ |locale|
          lang = I18nVariable.first(:conditions => {:key => locale})[locale]
          if I18n.locale.to_s.eql?(locale)
            lang
          else
            "<a href='?locale=#{locale}'>#{lang}</a>"
          end
        }.join(' | ')
      end
      c.define_tag 'link' do |tag|
        item = Item.first(:conditions => { :full_name => tag.attr['name'] })
        ret = ''
        ret << "<a href='#{tag.attr['name']}'>"
        ret << item.i18n_variable[I18n.locale]
        ret << '</a>'
      end
      c.define_tag 'menu' do |tag|
        home = get_homepage
        menu = page.design.layout.menu
        menu_level(home, 0, menu)
      end
    end
  end
  
  def parse_page(page, id = nil)
    if page._type == 'Page'
      context = parser_context(page, {}, id)
      parser = Radius::Parser.new(context, :tag_prefix => 'r')
      parser.parse(parser.parse(page.design.layout.body))
    end
  end
  
  def self.included(base)
    base.send :helper_method, :parse_page if base.respond_to? :helper_method
  end



  require 'nokogiri'

  def parse_page_noko(page, id = nil)
    body = Nokogiri::HTML(page.design.layout.body)

    # page_contents
    body.css('.page_content').each do |content|
      ret = ''
      if (content["main"] == "true" && !page.module_app.nil?)
        ret << "<div id='appfrontend' class='dymanic_load' path='/panel/#{page.module_app.key}/front_end/#{page.app_frontend_url}"
        ret << "/#{id}" if id
        ret << "?inner=true&page_id=#{page.id}"
        ret << "&category_id=#{page.category}" if page[:category]
        ret << "'></div>"
      else
        part = page.page_parts.detect{ |p| p.name.to_s == content['name'].to_s } rescue nil
        case part.kind
        when 'text'
          ret << part.i18n_variable[I18n.locale] rescue ''
        when 'module_widget'
          if part[:category]
            ret << "<div class='dymanic_load' path='/panel/#{part.module_app.key}/widget/#{part.widget_path}?inner=true&category_id=#{part[:category]}'></div>"
          else
            ret << "<div class='dymanic_load' path='/panel/#{part.module_app.key}/widget/#{part.widget_path}?inner=true'></div>"
          end
        when 'public_r_tag'
          ret << "<r:#{part.public_r_tag} id='#{part.public_r_tag_object_id}'/>"
        else
            ''
        end
      end
      scope = "<#{content.name}"
      content.attributes.each_pair do |key, value|
        scope << " #{key}='#{value}'"
      end
      scope << ">#{ret}</#{content.name}>"
      fragment = Nokogiri::HTML::DocumentFragment.new(body, scope)
      content.swap(fragment)
    end

    # page_menu
    page_menu = body.css('.page_menu').first
    home = get_homepage
    menu = page.design.layout.menu
    fragment = Nokogiri::HTML::DocumentFragment.new(body, menu_level(home, 0, menu))
    page_menu.swap(fragment)

    # page_image
    body.css('.page_image').each do |page_image|
      # image = page.custom_images.detect{|image| image.name.eql?(tag.attr['name']) }
      # image = page.design.custom_images.detect{|image| image.name.eql?(tag.attr['name']) } unless image
      image = page.design.images.detect{|image| image.name.eql?(page_image['name']) } unless image
      if image
        res = "<img src=#{image.file.url} "
        page_image.attributes.each do |l|
          res << "#{l[0]}='#{l[1]}' "
        end
        res << '>'
      end
      fragment = Nokogiri::HTML::DocumentFragment.new(body, res)
      page_image.swap(fragment)
    end

    # ad_banner
    body.css('ad_banner').each do |banner|
      res = ''
      ad_banner = AdBanner.find(banner["id"]) rescue nil
      if ad_banner && ad_banner.display?
        res << "<script type='text/javascript'>
                $(document).ready(function(){ $('#slideshow-#{ad_banner.title.dehumanize}').cycle({delay: -1000, fx: '#{ad_banner.ad_fx.nil?? 'fade': ad_banner.ad_fx}', timeoutFn: getTimeout }); });
                </script>"
        res << "<div id='slideshow-#{ad_banner.title.dehumanize}'>"
         ad_banner.ad_images.each do |ad_image|
           res << "<img src='#{ad_image.file}' "
           res << "alt='#{ad_image.picture_intro || ' '}' "
           res << "time_to_next='#{ad_image.get_delay_time}' "
           res << "link_open='#{ad_image.link_open}' "
           res << "link_url='#{(ad_banner.direct_to_after_click?? ad_image.out_link : ad_banner.context) || ' '}' "
           res << "/>"
          end
        res << "</div>"
      end
      fragment = Nokogiri::HTML::DocumentFragment.new(body, res)
      banner.swap(fragment)
    end

    body.to_html
  end
  
end
